#
#++
#
#  Copyright Digital Equipment Corporation 1996, 1997. All Rights Reserved.
#
#  Restricted Rights: Use, duplication, or disclosure by the U.S. Government
#  is subject to restrictions as set forth in subparagraph (c)(1)(ii) of DFARS
#  252.227-7013, or in FAR 52.227-19, or in FAR 52.227-14 Alt. III, as
#  applicable.
#
#  This software is proprietary to and embodies the confidential technology of
#  Digital Equipment Corporation. Possession, use, or copying of this software
#  and media is authorized only pursuant to a valid written license from
#  Digital or an authorized sublicensor.
#
#--
#
#++
#
#  MODULE:
#
#      D_TCP.DDL
#
#  ABSTRACT:
#
#	DDL program to decode TCP packets.
#
#  AUTHORS:
#
#      A A Hart
#
#  DATE:
#
#      22 Feb 1997
#
#  MODIFICATION HISTORY:
#
#	11-Jul-1997	A A Hart
#	Move the TYPES="TCP" to pst_tcp from pst_tcps to allow the TCP
#	header to be decoded.
#
INCLUDE ddlinc.ddl

# CONSTANTs
#
CONSTANT 
	TCP_source_port =                 0,
	TCP_destination_port =            2,
  	TCP_sequence_number =             4,
	TCP_acknowledge_number =          8,
	TCP_offset =                     12,
	TCP_flags =                      13,
	TCP_window =                     14,
	TCP_checksum =                   16,
	TCP_urgent =                     18;

# Name Table
# TCP Ports
NAME_TABLE TcpPorts {
    TITLE = "TCP Port"
    };


# TCP Flags Table
#
FLAG_TABLE TcpFlags {
    TITLE = "TCP flags"
    } =
	0x01 = "FIN",
	0x02 = "SYN",
	0x04 = "RST",
	0x08 = "PSH",
	0x10 = "ACK",
	0x20 = "URG"
	;


# PST: pst_tcps
# Main entry point for TCP packets.  This PST switches on the source port,
# if it doesn't find a match it calls the pst_tcpd pst to switch on the
# destination TCP port.
#
# CO = TCP Header
#
DECLARE PST pst_tcpd;
DECODE d_tcps(0) { NEXT = pst_tcpd, PLEVEL = HL_TCP } = ;
PST pst_tcps( word(TCP_source_port) ) {
	TITLE = "TCP port",
	DEFAULT = d_tcps
	} =
		;


# PST: pst_tcpd
# Secondary entry point for TCP packets.  This PST switches on the destination
# port, if it doesn't find a match it calls the default_tcp_types builtin.
#
# CO = TCP Header
#
DECLARE PST default_tcp_types;
DECODE d_tcpd(0) { NEXT = default_tcp_types } = ;
PST pst_tcpd( word(TCP_destination_port) ) {
	TITLE = "TCP port",
	DEFAULT = d_tcpd
	} =
		;



# DECODE: d_tcp4
# Output the IP V4 TCP header, the checksum is not output.
#
# CO = TCP Header
#
DECODE d_tcp4(0) {
	NEXT = pst_tcps
	} = 
		name( "Source port", TcpPorts, word(TCP_source_port) ),
		name( "Destination port", TcpPorts, word(TCP_destination_port) ),
		hex( long(TCP_sequence_number), 8, "TCP sequence" ),
		flags( byte(TCP_flags), 0, TcpFlags ),
		hex( long(TCP_acknowledge_number), 8, "TCP acknowledge" ),
		$1 = byte(TCP_offset),
		$1 = $1 / 4,
		decimal( $1, 0, "TCP header length" ),
		hex( word(TCP_window), 4, "TCP window" ),
		hex( word(TCP_urgent), 4, "Urgent pointer" )
		;


# DECODE: d_tcp
# Verify and output the TCP checksum and then consume the IP header and
# invoke the main TCP PST.
#
# CO = IP V4 header.
# $32 = IP header length (in bytes)
#
DECLARE PST pst_tcp, pst_ip_protocols;
DECODE d_tcp(6) {
	TITLE = "TCP",
	ATTACH = pst_ip_protocols,
	PLEVEL = HL_TCP,
	NEXT = pst_tcp,
	CONSUME = $32
	} =
		header_checksum( TCP_checksum, 0, "Verified TCP checksum" )
		;


# PST: pst_tcp
# Main PST for TCP, this simply invokes the d_tcp4 decode.
#
PST pst_tcp(0) { DEFAULT = d_tcp4, TYPE = "TCP" } = ;



