# ++
# ddl.ddl - Standard include file for DDL
#
# Modification History:
#
#	001	A A Hart	25-Apr-1997
#	Original
#
# --

# Standard parameter defintions.
#
CONSTANT BRIEF = 65535, ALWAYS = 65536;
CONSTANT DONT_TRANSLATE = 1, TRANSLATE = 0;
CONSTANT SECONDS = 1, MILLISECONDS = 1000, MICROSECONDS = 1000000, NANOSECONDS = 1000000000;
CONSTANT DONT_REVERSE = 0, REVERSE = 1;

#
# Header levels and ranges.  Each protocol has its own level (within an appropriate range), the
# tdd_protocol_to_range() routine translates a protocol (or layer) name into a min/max range.  Note
# that the layers only roughly correspond to the ISO ot TCP/IP models.
#
CONSTANT

# Internal
# used for data generated internally by the router 
# Range =	 50,   99
#
	HL_ICC =		 51,
	HL_PRAM =		 52,

# Physical layer
# modem control, sync framing etc 
# Range =	 100, 199
#
	HL_MODEM =	 	101,

# multiplex layer 
# equivalent to the address fields on LANs
# Range =	 500,999
#
	HL_FRBS =		 501,

# Datalink layer 
# the first protocol header.
# Range =	1000,1999
#
	HL_LAPB =		1001,
	HL_PSL =		1002,
	HL_ENET =		1003,
	HL_FDDI =		1004,
	HL_HDLC =		1005,
	HL_CHDLC =		1006,
	HL_PPP =		1007,
	HL_DDCMP =		1008,
	HL_LAPBE =		1009,
	HL_I8023 =		1010,
	HL_I8025 =		1011,
	HL_MPI =		1012,
	HL_TR =			1013,
	HL_LAPF =		1014,
	HL_LAPD =		1015,

# LLC layer
# enacapsulated within the DL layer, not always present (e.g. Ethernet)
# Range =		2000,2999
#
	HL_LLC2 =		2001,
	HL_I8022 =		2002,

# Bridge/datalink apps
# protocols that don't require a network layer 
# Range =	3000,3999
#
	HL_BRIDGE =		3001,
	HL_MOP =		3002,
	HL_ARP =		3003,
	HL_AARP =		3004,
	HL_LAT =		3005,
	HL_CTP =		3006,

# Network layer 
# Range =	4000,4999
#
	HL_X25L3 =		4001,
	HL_IP =			4002,
	HL_IPX =		4003,
	HL_PIV =		4004,
	HL_OSI =		4005,
	HL_ATLK =		4006,
	HL_IPV6 =		4007,

# Routing layer
# protocols which are enacpsulated within the network layer and don't require a
# transport layer. 
# Range =	5000,5699
#
	HL_OSPF =		5001,
	HL_ISIS =		5002,
	HL_IGMP =		5003,
	HL_ICMP =		5004,
	HL_IGRP =		5005,
	HL_PIM =		5706,
	HL_RSVP =		5707,

# Routing layer 2 
# Range =	5700,5999
#
	HL_DVMRP =		5702,

# Transport layer 
# Range =	6000,6999
#
	HL_UDP =		6001,
	HL_TCP =		6002,
	HL_NSP =		6003,
	HL_OSITP =		6004,

# Application layer 
# protocols encapsulated within one of the trasnport protocols.
# Range =	7000,7999
#
	HL_SC =			7001,
	HL_BGP =		7002,
	HL_RIP =		7003,
	HL_ASN1 =		7004,
	HL_CMIP =		7005,
	HL_SNMP =		7006,
	HL_BOOTP =		7007,
	HL_VRC =		7008,
	HL_NETBIOS =		7009,
	HL_SMB =		7010,
	HL_IFMP =		7011,

# Data
# Range =		20000,20999
#
	HL_COMMENT =		20001,
	HL_SECCON =		20002,

	HL_ZERO =		0,
	HL_MIN =		1,
	HL_UNKNOWN =		65533,
	HL_MAX =		65534;



